clear
set more off

*************
* Summarize voting behavior statistics.
* Plot distributions and look at correlation of measures
* across parameter values.
*************

* Get own path here
global home "/users/nick/Dropbox/Joint_Projects/GAPP/QJPS_ReplicationPackage_EGPR"

cd "$home"

use 1_data/network_and_voting_stats.dta, clear

* 8785 Stats
sum vcount_friend if VILLAGE == "8785"
local clean_corr: display %9.0f `r(mean)'
display "`clean_corr'"
file open myfile using 3_results/outlier_size.tex, write text replace
file write myfile "`clean_corr'"
file close myfile


drop if VILLAGE =="8785"



* Turnout correlations across types
twoway (lfitci pres_turnout_adultpop LC5chair_turnout_adultpop) ///
       (scatter pres_turnout_adultpop LC5chair_turnout_adultpop), ///
   ytitle("Presidential Turnout") ///
   xtitle("LC5 Turnout")

graph export 3_results/summary_turnout.pdf, replace


foreach i in pres_turnout_adultpop pres_blockvoting pres_viable ///
             LC5chair_turnout_adultpop LC5chair_blockvoting LC5chair_viable ///
             LC5coun_turnout_adultpop LC5coun_blockvoting {
                 count if `i' != .
                 local num = r(N)
                 sum `i'
                 twoway(hist `i', bin(4)), note("N: `num', mean: `r(mean)'")
                 tempfile `i'
                 graph save ``i''.gph, replace
                 graph export 3_results/summary_`i'.pdf, replace

             }

graph combine `pres_turnout_adultpop'.gph `pres_blockvoting'.gph `pres_viable'.gph ///
            `LC5chair_turnout_adultpop'.gph `LC5chair_blockvoting'.gph `LC5chair_viable'.gph ///
            `LC5coun_turnout_adultpop'.gph `LC5coun_blockvoting'.gph, ///
            title("Voting Summary Stats")

graph export 3_results/voting_summary_graphs.pdf, replace

* Correlations across race types:
cd "$home"
corrtex pres_turnout_adultpop LC5chair_turnout_adultpop LC5coun_turnout_adultpop, ///
        file(3_results/corr_turnout) replace digits(2) title("Turnout") key("turnout_corr")

    * Save
    corr pres_turnout_adultpop LC5chair_turnout_adultpop
    local clean_corr: display %9.2f `r(rho)'
    display "`clean_corr'"
    file open myfile using 3_results/turnout_corr_coefficient.tex, write text replace
    file write myfile "`clean_corr'"
    file close myfile



corrtex pres_blockvoting LC5chair_blockvoting LC5coun_blockvoting, ///
        file(3_results/corr_blockvoting) replace digits(2) title("Block Voting")

corrtex pres_viable LC5chair_viable, ///
        file(3_results/corr_efficientvoting) replace digits(2) title("Efficient Voting")


hist avg_vil_concentration_pres, title("Village Voter Concentration") xtitle("Avg Village Votes as Share of Total Precinct Votes" "(Weighted Avg Across Precincts)")
graph export 3_results/concentration_hist.pdf, replace
